==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/TemplateRepositoryServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.data.TemplateRepository;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class TemplateRepositoryServiceImpl implements ITemplateRepositoryService {

    /**
     * Obtains a new DataSet for the TemplateRepository entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<TemplateRepository> getTemplateRepositoryDataSet() {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, HibernateUtil.getSessionFactory("DIFRepository"),
                TemplateRepository.getPKFieldListAsString(), TemplateRepository.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == TemplateRepository.class)
            return getTemplateRepositoryDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(TemplateRepository.class.getSimpleName()))
            return getTemplateRepositoryDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/TemplateRepositoryServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.ITemplateRepositoryService;
import pt.digitalis.dif.dem.managers.impl.model.data.TemplateRepository;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class TemplateRepositoryServiceImpl implements ITemplateRepositoryService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the TemplateRepository entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<TemplateRepository> getTemplateRepositoryDataSet() {
        return new HibernateDataSet<TemplateRepository>(TemplateRepository.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                TemplateRepository.getPKFieldListAsString(), TemplateRepository.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == TemplateRepository.class)
            return getTemplateRepositoryDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(TemplateRepository.class.getSimpleName()))
            return getTemplateRepositoryDataSet();

        return null;
    }
}
